@@ -1,5 +1,5 @@
 package Limper::SendFile;
-$Limper::SendFile::VERSION = '0.004';
+$Limper::SendFile::VERSION = '0.005';
 use base 'Limper';
 use 5.10.0;
 use strict;
@@ -47,7 +47,7 @@ hook after => sub {
 };
 
 sub send_file {
-    my ($file) = @_ || request->{uri};
+    my $file = $_[0] // request->{uri};
 
     $file =~ s{^/}{$public/};
     if ($file =~ qr{/\.\./}) {
@@ -65,7 +65,9 @@ sub send_file {
         } elsif (-d $file) {
             opendir(my $dh, $file);
             my @files = sort grep { !/^\./ } readdir $dh;
-            @files = map { "<a href=\"$_\">$_</a><br>" } @files;
+            my $path = request->{uri};
+            $path .= '/' unless $path =~ m|/$|;
+            @files = map { "<a href=\"$path$_\">$_</a><br>" } @files;
             headers 'Content-Type' => 'text/html';
             join "\n", '<html><head><title>Directory listing of ' . request->{uri} . '</title></head><body>', @files, '</body></html>';
         } else {
@@ -88,7 +90,7 @@ Limper::SendFile - add static content support to Limper
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
